var DEOTHEMES = DEOTHEMES || {};

(function ($) {
	DEOTHEMES.initialize = {
		init: function () {
			DEOTHEMES.initialize.scrollToTop();
			DEOTHEMES.initialize.menuAccessibility();
			DEOTHEMES.initialize.mobileAccessibility();
			DEOTHEMES.initialize.mobileNavigation();
			DEOTHEMES.initialize.masonry();
			DEOTHEMES.initialize.responsiveTables();
			DEOTHEMES.initialize.skipLinkFocus();
			DEOTHEMES.initialize.detectMobile();
		},

		preloader: function () {
			var loaderMask = document.querySelector(".loader-mask");
			var loader = document.querySelector(".loader");
			const bar = document.querySelector(".loader-bar span");

			if (!loader) return;

			bar.style.width = "100%";

			setTimeout(function () {
				loader.style.opacity = "0";
			}, 400);

			setTimeout(function () {
				loaderMask.style.height = "0";
			}, 800);

			loaderMask.addEventListener("transitionend", function () {
				setTimeout(function () {
					loaderMask.remove();
				}, 200);
			});
		},

		triggerResize: function () {
			resizeEvent.initUIEvent("resize", true, false, window, 0);
			window.dispatchEvent(resizeEvent);
		},

		scrollToTopScroll: function () {
			var scroll = window.scrollY;
			if (!backToTop) {
				return;
			}

			if (scroll >= 50) {
				backToTop.classList.add("show");
			} else {
				backToTop.classList.remove("show");
			}
		},

		scrollToTop: function () {
			if (!backToTop) {
				return;
			}

			backToTop.addEventListener("click", function (e) {
				e.preventDefault();

				if (document.scrollingElement.scrollTop === 0) return;
				var totalScrollDistance = document.scrollingElement.scrollTop;
				var scrollY = totalScrollDistance,
					oldTimestamp = null;

				function step(newTimestamp) {
					if (oldTimestamp !== null) {
						scrollY -=
							(totalScrollDistance * (newTimestamp - oldTimestamp)) / 350;
						if (scrollY <= 0) return (document.scrollingElement.scrollTop = 0);
						document.scrollingElement.scrollTop = scrollY;
					}
					oldTimestamp = newTimestamp;
					window.requestAnimationFrame(step);
				}
				window.requestAnimationFrame(step);
			});
		},

		menuAccessibility: function () {
			// Get all the link elements within the primary menu.
			var i,
				links = document.querySelectorAll(
					".eversor-nav-menu__item, .nav__menu a"
				),
				menu = document.querySelectorAll(".eversor-nav-menu__list, .nav__menu");

			if (0 === menu.length) {
				return false;
			}

			// Each time a menu link is focused or blurred, toggle focus.
			for (i = 0; i < links.length; i++) {
				links[i].addEventListener("focus", toggleFocus, true);
				links[i].addEventListener("blur", toggleFocus, true);
			}

			function hasClass(element, className) {
				return (
					(" " + element.className + " ").indexOf(" " + className + " ") > -1
				);
			}

			// Sets or removes the .focus class on an element.
			function toggleFocus() {
				var self = this;
				menu = hasClass(self, "eversor-nav-menu__item")
					? "eversor-nav-menu__list"
					: "nav__menu";

				// Move up through the ancestors of the current link until we hit menu list class.
				while (-1 === self.className.indexOf(menu)) {
					// On li elements toggle the class .focus.
					if ("li" === self.tagName.toLowerCase()) {
						if (-1 !== self.className.indexOf("focus")) {
							self.className = self.className.replace(" focus", "");
						} else {
							self.className += " focus";
						}
					}
					self = self.parentElement;
				}
			}
		},

		mobileAccessibility: function () {
			document.addEventListener("keydown", function (e) {
				var tabKey,
					shiftKey,
					selectors,
					elements,
					mobileMenu,
					activeEl,
					lastEl,
					firstEl;

				if (body.classList.contains("showing-modal")) {
					selectors =
						'button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])';
					activeEl = document.activeElement;

					// Search
					if (body.classList.contains("showing-search-modal")) {
						let search = document.querySelectorAll(".dorya-menu-search");

						for (var i = 0; i < search.length; i++) {
							firstEl = search[i].querySelector(".search-input");
							lastEl = search[i].querySelector(".search-button");
							trapFocus(firstEl, lastEl);
						}
					}

					// Nav
					if (body.classList.contains("showing-nav-modal")) {
						mobileMenu = document.querySelector(".nav__wrap");
						firstEl = document.querySelector("#nav__icon-toggle");
						elements = mobileMenu.querySelectorAll(selectors);
						elements = Array.prototype.slice.call(elements);

						elements = elements.filter(function (element) {
							return null !== element.offsetParent;
						});

						lastEl = elements[elements.length - 1];

						trapFocus(firstEl, lastEl);
					}

					function trapFocus(firstEl, lastEl) {
						tabKey = e.key === "Tab" || e.keyCode === 9;
						shiftKey = e.shiftKey;

						if (!shiftKey && tabKey && lastEl === activeEl) {
							e.preventDefault();
							firstEl.focus();
						}

						if (shiftKey && tabKey && firstEl === activeEl) {
							e.preventDefault();
							lastEl.focus();
						}
					}
				}
			});
		},

		stickyNavbar: function () {
			var doc = document.documentElement;

			var prevScroll = window.scrollY || doc.scrollTop;
			var curScroll;
			var direction = 0;
			var prevDirection = 0;

			var header = document.querySelector(".nav--sticky");
			if (!header) return;
			var headerHeight = header.offsetHeight;

			var checkScroll = function () {
				curScroll = window.scrollY || doc.scrollTop;
				if (curScroll > prevScroll) {
					direction = 2;
				} else if (curScroll < prevScroll) {
					direction = 1;
				}

				if (direction !== prevDirection) {
					toggleHeader(direction, curScroll);
				}

				prevScroll = curScroll;
			};

			var toggleHeader = function (direction, curScroll) {
				// Down
				if (direction === 2 && curScroll > headerHeight) {
					header.classList.add("nav--sticky--is-sticky");
					header.classList.remove("nav--sticky--is-scrolling");
					prevDirection = direction;
				}
				// Up
				else if (direction === 1) {
					header.classList.remove("nav--sticky--is-sticky");
					header.classList.add("nav--sticky--is-scrolling");
					prevDirection = direction;
				}

				// Top
				if (direction === 1 && curScroll === 0) {
					header.classList.remove("nav--sticky--is-scrolling");
				}
			};

			window.addEventListener("scroll", checkScroll);
		},

		mobileNavigation: function () {
			// Mobile toggle
			(function () {
				let navIconToggle = document.querySelectorAll(".nav__icon-toggle");
				for (let i = 0; i < navIconToggle.length; i++) {
					navIconToggle[i].addEventListener("click", function () {
						this.setAttribute("disabled", "");
						body.classList.toggle("showing-modal");
						body.classList.toggle("showing-nav-modal");
						this.classList.toggle("nav__icon-toggle--is-opened");
						setTimeout(() => {
							this.removeAttribute("disabled");
						}, 350);
					});
				}
			})();

			// Dropdowns
			var navDropdown = document.querySelector(".nav__dropdown");
			var navDropdownMenu = document.querySelector(".nav__dropdown-menu");
			var navDropdownTrigger = document.querySelectorAll(
				".nav__dropdown-trigger"
			);

			if (navDropdownTrigger) {
				for (let i = 0; i < navDropdownTrigger.length; i++) {
					navDropdownTrigger[i].addEventListener("click", function () {
						this.classList.toggle("nav__dropdown-trigger--is-open");

						let menuSiblings = DEOTHEMES.getSiblings(this.parentElement);

						menuSiblings.forEach((sibling) => {
							let trigger = sibling.querySelector(".nav__dropdown-trigger");
							if (trigger) {
								trigger.classList.remove("nav__dropdown-trigger--is-open");
								DEOTHEMES.DOMAnimations.slideUp(trigger.nextElementSibling);
								trigger.setAttribute("aria-expanded", "false");
							}
						});

						DEOTHEMES.DOMAnimations.slideToggle(this.nextElementSibling);

						let attr = this.getAttribute("aria-expanded");
						if (attr == "true") {
							this.setAttribute("aria-expanded", "false");
						} else {
							this.setAttribute("aria-expanded", "true");
						}
					});
				}
			}

			if (html.classList.contains("mobile")) {
				body.addEventListener("click", function () {
					navDropdownMenu.classList.add("hide-dropdown");
				});

				navDropdown.addEventListener("click", "> a", function (e) {
					e.preventDefault();
				});

				navDropdown.addEventListener("click", function (e) {
					e.stopPropagation();
					navDropdownMenu.classList.remove("hide-dropdown");
				});
			}
		},

		stickyFooter: function () {
			const footer = document.querySelector(".footer");
			const footerPlaceholder = document.querySelector(".footer-placeholder");
			if (!footerPlaceholder) {
				return;
			}

			const footerHeight = footer.offsetHeight;
			footerPlaceholder.style.height = footerHeight + "px";
		},

		masonry: function () {
			let grid = document.getElementById("masonry-grid");

			if (!grid) {
				return;
			}

			var masonry = new Masonry(grid, {
				columnWidth: ".masonry-item",
				itemSelector: ".masonry-item",
				percentPosition: true,
			});

			imagesLoaded(grid).on("progress", function () {
				masonry.layout();
			});
		},

		responsiveTables: function () {
			let tables = document.querySelectorAll(".wp-block-table");

			if (!tables.length > 0) {
				return;
			}

			for (var i = 0; i < tables.length; i++) {
				let table = tables[i].innerHTML;
				let tableResponsive =
					'<div class="table-responsive">' + table + "</div>";
				tables[i].innerHTML = tableResponsive;
			}
		},

		skipLinkFocus: function () {
			var isIe = /(trident|msie)/i.test(navigator.userAgent);

			if (isIe && document.getElementById && window.addEventListener) {
				window.addEventListener(
					"hashchange",
					function () {
						var id = location.hash.substring(1),
							element;

						if (!/^[A-z0-9_-]+$/.test(id)) {
							return;
						}

						element = document.getElementById(id);

						if (element) {
							if (
								!/^(?:a|select|input|button|textarea)$/i.test(element.tagName)
							) {
								element.tabIndex = -1;
							}

							element.focus();
						}
					},
					false
				);
			}
		},

		detectMobile: function () {
			if (
				/Android|iPhone|iPad|iPod|BlackBerry|Windows Phone/i.test(
					navigator.userAgent || navigator.vendor || window.opera
				)
			) {
				html.classList.add("mobile");
			} else {
				html.classList.remove("mobile");
			}
		},
	};

	DEOTHEMES.getSiblings = function (e) {
		let siblings = [];
		if (!e.parentNode) {
			return siblings;
		}
		let sibling = e.parentNode.firstChild;

		while (sibling) {
			if (sibling.nodeType === 1 && sibling !== e) {
				siblings.push(sibling);
			}
			sibling = sibling.nextSibling;
		}
		return siblings;
	};

	DEOTHEMES.debounce = function (func, time) {
		var time = time || 300;
		var timer;
		return function (event) {
			if (timer) clearTimeout(timer);
			timer = setTimeout(func, time, event);
		};
	};

	DEOTHEMES.DOMAnimations = {
		/**
		 * SlideUp
		 *
		 * @param {HTMLElement} element
		 * @param {Number} duration
		 * @returns {Promise<boolean>}
		 */
		slideUp: function (element, duration = 500) {
			return new Promise(function (resolve, reject) {
				element.style.height = element.offsetHeight + "px";
				element.style.transitionProperty = `height, margin, padding`;
				element.style.transitionDuration = duration + "ms";
				element.offsetHeight;
				element.style.overflow = "hidden";
				element.style.height = 0;
				element.style.paddingTop = 0;
				element.style.paddingBottom = 0;
				element.style.marginTop = 0;
				element.style.marginBottom = 0;
				window.setTimeout(function () {
					element.style.display = "none";
					element.style.removeProperty("height");
					element.style.removeProperty("padding-top");
					element.style.removeProperty("padding-bottom");
					element.style.removeProperty("margin-top");
					element.style.removeProperty("margin-bottom");
					element.style.removeProperty("overflow");
					element.style.removeProperty("transition-duration");
					element.style.removeProperty("transition-property");
					resolve(false);
				}, duration);
			});
		},

		/**
		 * SlideDown
		 *
		 * @param {HTMLElement} element
		 * @param {Number} duration
		 * @returns {Promise<boolean>}
		 */
		slideDown: function (element, duration = 500) {
			return new Promise(function (resolve, reject) {
				element.style.removeProperty("display");
				let display = window.getComputedStyle(element).display;

				if (display === "none") display = "block";

				element.style.display = display;
				let height = element.offsetHeight;
				element.style.overflow = "hidden";
				element.style.height = 0;
				element.style.paddingTop = 0;
				element.style.paddingBottom = 0;
				element.style.marginTop = 0;
				element.style.marginBottom = 0;
				element.offsetHeight;
				element.style.transitionProperty = `height, margin, padding`;
				element.style.transitionDuration = duration + "ms";
				element.style.height = height + "px";
				element.style.removeProperty("padding-top");
				element.style.removeProperty("padding-bottom");
				element.style.removeProperty("margin-top");
				element.style.removeProperty("margin-bottom");
				window.setTimeout(function () {
					element.style.removeProperty("height");
					element.style.removeProperty("overflow");
					element.style.removeProperty("transition-duration");
					element.style.removeProperty("transition-property");
				}, duration);
			});
		},

		/**
		 * SlideToggle
		 *
		 * @param {HTMLElement} element
		 * @param {Number} duration
		 * @returns {Promise<boolean>}
		 */
		slideToggle: function (element, duration = 500) {
			if (window.getComputedStyle(element).display === "none") {
				return this.slideDown(element, duration);
			} else {
				return this.slideUp(element, duration);
			}
		},
	};

	DEOTHEMES.documentOnReady = {
		init: function () {
			DEOTHEMES.initialize.init();
		},
	};

	DEOTHEMES.windowOnLoad = {
		init: function () {
			DEOTHEMES.initialize.preloader();
			DEOTHEMES.initialize.triggerResize();
		},
	};

	DEOTHEMES.windowOnResize = {
		init: function () {
			DEOTHEMES.initialize.stickyFooter();
		},
	};

	DEOTHEMES.windowOnScroll = {
		init: function () {
			DEOTHEMES.initialize.scrollToTopScroll();
			DEOTHEMES.initialize.stickyNavbar();
		},
	};

	var html = document.querySelector("html"),
		body = document.body,
		backToTop = document.getElementById("back-to-top"),
		tabletBreakpoint = 1025,
		belowTablet = window.matchMedia("(max-width: 1024px)"),
		aboveTablet = window.matchMedia("(min-width: 1025px)"),
		resizeEvent = window.document.createEvent("UIEvents");

	document.addEventListener("DOMContentLoaded", DEOTHEMES.documentOnReady.init);
	window.addEventListener("load", DEOTHEMES.windowOnLoad.init);
	window.addEventListener(
		"resize",
		DEOTHEMES.debounce(DEOTHEMES.windowOnResize.init)
	);
	window.addEventListener("scroll", DEOTHEMES.windowOnScroll.init);
})(jQuery);
