<?php
/**
 * Theme functions and definitions.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Dorya
 * @since 		 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) {
	$content_width = 1280; /* pixels */
}

// Constants
define( 'DORYA_VERSION', '1.0.1' );
define( 'DORYA_DIR', get_template_directory() );
define( 'DORYA_URI', get_template_directory_uri() );

// Includes
require_once DORYA_DIR . '/includes/admin/theme-admin.php';
require_once DORYA_DIR . '/includes/theme-setup.php';
require_once DORYA_DIR . '/includes/theme-functions.php';
require_once DORYA_DIR . '/includes/theme-hooks.php';
require_once DORYA_DIR . '/includes/template-tags.php';
require_once DORYA_DIR . '/includes/template-parts.php';
require_once DORYA_DIR . '/includes/class-dorya-breadcrumb-trail.php';
require_once DORYA_DIR . '/includes/class-dorya-query.php';
require_once DORYA_DIR . '/includes/class-dorya-walker-nav-menu.php';
require_once DORYA_DIR . '/includes/class-dorya-walker-comment.php';
require_once DORYA_DIR . '/includes/customizer/customizer.php';

/**
 * Theme update functions.
 */
require_once DORYA_DIR . '/includes/theme-update/class-dorya-theme-update.php';

/**
* TGM plugins activation.
*/
require_once DORYA_DIR . '/includes/tgmpa/tgm-plugin-activation.php';

/**
* Demo Import.
*/
require_once DORYA_DIR . '/includes/theme-demo-import.php';


/**
* Theme Wizard.
*/
require_once get_parent_theme_file_path( '/includes/merlin/vendor/autoload.php' );
require_once get_parent_theme_file_path( '/includes/merlin/class-merlin.php' );
require_once get_parent_theme_file_path( '/includes/merlin/merlin-config.php' );
require_once get_parent_theme_file_path( '/includes/merlin/merlin-filters.php' );


/**
 * Theme styles.
 */
function dorya_theme_styles() {
	wp_enqueue_style( 'dorya-styles', DORYA_URI . '/assets/css/style.min.css', array(), DORYA_VERSION, 'all' );
	wp_style_add_data( 'dorya-styles', 'rtl', 'replace' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Editor shared styles
	wp_enqueue_style( 'dorya-block-editor-shared-styles', get_theme_file_uri( '/assets/css/editor-shared.min.css' ), false );
	wp_style_add_data( 'dorya-block-editor-shared-styles', 'rtl', 'replace' );

	// Fonts
	if ( ! class_exists( 'Kirki' ) ) {
		wp_enqueue_style( 'dorya-google-fonts', '//fonts.googleapis.com/css2?family=Archivo:ital,wght@0,400;0,700;1,400&family=Montserrat:wght@400;700&display=swap', [], null );
	}
}
add_action( 'wp_enqueue_scripts', 'dorya_theme_styles' );

/**
 * Block editor styles.
 */
function dorya_block_assets() {
	wp_enqueue_style( 'dorya-block-editor-styles', get_theme_file_uri( '/assets/css/editor.min.css' ), false );
	wp_style_add_data( 'dorya-block-editor-styles', 'rtl', 'replace' );

	// Editor shared styles
	wp_enqueue_style( 'dorya-block-editor-shared-styles', get_theme_file_uri( '/assets/css/editor-shared.min.css' ), false );
	wp_style_add_data( 'dorya-block-editor-shared-styles', 'rtl', 'replace' );

	// Adobe fonts
	if ( function_exists( 'dorya_get_typekit_fonts') ) {
		$typekit_fonts = dorya_get_typekit_fonts();
	}

	if ( ! empty( $typekit_fonts ) ) {			
		$typekit_info = get_option( 'dorya-typekit-fonts' );
		$typekit_id = $typekit_info['custom-typekit-font-id'];

		if ( ! empty( $typekit_id ) ) {
			wp_enqueue_style( 'dorya-typekit-fonts', '//use.typekit.net/' . $typekit_id . '.css' );
		}
	}
	
	if ( ! class_exists( 'Kirki' ) || empty( $typekit_fonts ) ) {
		wp_enqueue_style( 'dorya-block-editor-google-fonts', '//fonts.googleapis.com/css2?family=Archivo:ital,wght@0,400;0,700;1,400&family=Montserrat:wght@400;700&display=swap', [], null );
	}
}
add_action( 'enqueue_block_editor_assets', 'dorya_block_assets' );


/**
 * Theme scripts.
 */
function dorya_theme_scripts() {
	if ( is_archive() || is_search() || is_home() ) {
		wp_enqueue_script( 'masonry' );
		wp_enqueue_script( 'imagesloaded' );
	}
	wp_enqueue_script( 'bootstrap', DORYA_URI . '/assets/js/vendor/min/bootstrap.min.js', array(), DORYA_VERSION, true );
	wp_enqueue_script( 'body-scroll-lock', DORYA_URI . '/assets/js/vendor/min/bodyScrollLock.min.js', array(), DORYA_VERSION, true );
	wp_enqueue_script( 'dorya-scripts', DORYA_URI . '/assets/js/scripts.min.js', array(), DORYA_VERSION, true );

	// Dark Mode
	if ( get_theme_mod( 'dorya_settings_dark_mode', false ) ) {
		wp_enqueue_script( 'dorya-dark-mode', DORYA_URI . '/assets/js/dark-mode.min.js', array(), DORYA_VERSION, false );
	}

	$Dorya_Data = array(
		'home_url' => esc_url( home_url( '/' ) ),
		'theme_path' => DORYA_URI
	);	
	wp_localize_script( 'dorya-scripts', 'Dorya_Data', $Dorya_Data );	
}

add_action( 'wp_enqueue_scripts', 'dorya_theme_scripts' );


/**
 * Theme admin scripts and styles.
 */
function dorya_admin_scripts() {
	$screen = get_current_screen();
	wp_enqueue_style( 'dorya-admin-styles', DORYA_URI . '/assets/admin/css/admin-styles.css' );
}
add_action( 'admin_enqueue_scripts', 'dorya_admin_scripts' );


/**
 * Customizer scripts and styles.
 */
function dorya_customizer_scripts() {
	wp_enqueue_style( 'dorya-customizer-styles', DORYA_URI . '/assets/css/customizer/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'dorya_customizer_scripts' );