<?php
/**
 * Theme admin functions.
 *
 * @package Dorya
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
* Add admin menu
*
* @since 1.0.0
*/
function dorya_theme_admin_menu() {
	add_theme_page(
		esc_html__( 'Dorya Getting Started', 'dorya' ),
		esc_html__( 'Dorya', 'dorya' ),
		'manage_options',
		'dorya-theme',
		'dorya_admin_page_content',
		30
	);
}
add_action( 'admin_menu', 'dorya_theme_admin_menu' );


/**
* Add admin page content
*
* @since 1.0.0
*/
function dorya_admin_page_content() {
	$theme = wp_get_theme();
	$theme_name = 'Dorya';
	$active_theme_name  = strtolower( preg_replace( '#[^a-zA-Z]#', '', $theme->template ) );
	$docs_url = 'https://docs.deothemes.com/dorya/knowledgebase/';

	$urls = array(
		'theme-url'									=> 'https://dorya.deothemes.com/',
		'rating-url'								=> 'https://wordpress.org/support/theme/dorya/reviews/?rate=5#new-post',
		'docs' 											=> 'https://docs.deothemes.com/dorya',
		'video-tutorials'						=> 'https://www.youtube.com/watch?v=MZhkxTkllIE&list=PLaPNmyRO67T3Zg9YCMWtlZraFivCz97eh&ab_channel=DeoThemes',
		'page-layout'								=> $docs_url . 'page-layout',
		'gdpr'											=> $docs_url . 'gdpr',
		'home-page-demos'						=> $docs_url . 'home-page-demos'
	);

	$buttons = array(
		'header' => array(
			'link_url'		 => admin_url( 'customize.php?autofocus[panel]=dorya_settings_header' ),
			'link_text'    => esc_html__( 'Header', 'dorya' ),
			'icon'    		 => 'dashicons dashicons-align-center',
		),
		'footer' => array(
			'link_url'		 => admin_url( 'customize.php?autofocus[section]=dorya_settings_footer' ),
			'link_text'    => esc_html__( 'Footer', 'dorya' ),
			'icon'				 => 'dashicons dashicons-align-full-width'
		),
		'layout' => array(
			'link_url'		 => admin_url( 'customize.php?autofocus[panel]=dorya_settings_layout' ),
			'link_text'    => esc_html__( 'Layout', 'dorya' ),
			'icon'				 => 'dashicons dashicons-layout'
		),
		'colors' => array(
			'link_url'		 => admin_url( 'customize.php?autofocus[panel]=dorya_settings_colors' ),
			'link_text'    => esc_html__( 'Colors', 'dorya' ),
			'icon'				 => 'dashicons dashicons-admin-appearance'
		),
		'typography' => array(
			'link_url'		 => admin_url( 'customize.php?autofocus[section]=dorya_settings_typography' ),
			'link_text'    => esc_html__( 'Typography', 'dorya' ),
			'icon'				 => 'dashicons dashicons-editor-textcolor'
		)
	);

	if ( defined( 'DORYA_CORE_VERSION' ) ) {
		$buttons['header'] = array(
			'link_url'		 => admin_url( 'edit.php?post_type=theme_template' ),
			'link_text'    => esc_html__( 'Header', 'dorya' ),
			'icon'    		 => 'dashicons dashicons-align-center',
		);
		$buttons['footer'] = array(
			'link_url'		 => admin_url( 'edit.php?post_type=theme_template' ),
			'link_text'    => esc_html__( 'Footer', 'dorya' ),
			'icon'				 => 'dashicons dashicons-align-full-width'
		);
		$buttons['adobe_fonts'] = array(
			'link_url'		 => admin_url( 'admin.php?page=dorya-core-custom-typekit-fonts' ),
			'link_text'    => esc_html__( 'Adobe Fonts', 'dorya' ),
			'icon'				 => 'dashicons dashicons-editor-spellcheck'
		);
		$buttons['custom_fonts'] = array(
			'link_url'		 => admin_url( 'edit-tags.php?taxonomy=dorya_core_custom_fonts' ),
			'link_text'    => esc_html__( 'Custom Fonts', 'dorya' ),
			'icon'				 => 'dashicons dashicons-editor-spellcheck'
		);
	}

	$videos = array(
		'theme-installation' => array(
			'links' => array(
				array(
					'link_url'		 => 'https://www.youtube.com/watch?v=vXjonvErGWY&ab_channel=DeoThemes',
					'link_text'    => esc_html__( 'Theme Installation', 'dorya' ),
					'link_img_src' => DORYA_URI . '/assets/admin/img/videos/dorya_video_demo_import.jpg'
				)
			)
		),
	);

	$info = array(
		'page-layouts' => array(
			'title'			=> esc_html__( 'Page Layout', 'dorya' ),
			'class'			=> 'dorya-addon-list-item',
			'title_url' => $urls['page-layout'],
			'links'			=> array(
				array(
					'link_class'	 => 'dorya-learn-more',
					'link_url'		 => $urls['page-layout'],
					'link_text'    => esc_html__( 'Learn More &#187;', 'dorya' ),
					'target_blank' => true
				),
			),
		),
		'gdpr' => array(
			'title'			=> esc_html__( 'GDPR Tools', 'dorya' ),
			'class'			=> 'dorya-addon-list-item',
			'title_url' => $urls['gdpr'],
			'links'			=> array(
				array(
					'link_class'	 => 'dorya-learn-more',
					'link_url'		 => $urls['gdpr'],
					'link_text'    => esc_html__( 'Learn More &#187;', 'dorya' ),
					'target_blank' => true
				),
			),
		),				
	);

	?>

		<div class="dorya-page-header">
			<div class="dorya-page-header__container">
				<div class="dorya-page-header__branding">
					<a href="<?php echo esc_url( $urls['theme-url'] ); ?>" target="_blank" rel="noopener" >
						<img src="<?php echo esc_url( DORYA_URI . '/assets/admin/img/theme_logo.png' ); ?>" class="dorya-page-header__logo" alt="<?php echo esc_attr__( 'Dorya', 'dorya' ); ?>" />
					</a>
					<span class="dorya-theme-version"><?php echo esc_html( DORYA_VERSION ); ?></span>
				</div>
				<div class="dorya-page-header__tagline">
					<span  class="dorya-page-header__tagline-text">				
						<?php echo esc_html__( 'Made by ', 'dorya' ); ?>
						<a href="https://deothemes.com/"><?php echo esc_html__( 'DeoThemes', 'dorya' ); ?></a>						
					</span>					
				</div>				
			</div>
		</div>

		<div class="wrap dorya-container">
			<div class="dorya-grid">

				<div class="dorya-grid-content">
					<div class="dorya-body">

						<h1 class="dorya-title"><?php esc_html_e( 'Getting Started', 'dorya' ); ?></h1>
						<p class="dorya-intro-text">
							<?php echo esc_html__( 'Dorya is now installed and ready to use. Get ready to build something beautiful. To get started check the links below. We hope you enjoy it!', 'dorya' ); ?>
						</p>
						
						<?php
							$wizard_completed = get_option( 'merlin_' . $active_theme_name . '_completed' );

							if ( ! $wizard_completed ) : ?>
								<a href="<?php echo esc_url( admin_url( 'themes.php?page=merlin' ) ); ?>" class="button button-primary button-hero">
									<?php echo esc_html__( 'Run Setup Wizard', 'dorya' ); ?>
								</a>
							<?php endif;
						?>

						<!-- Navigation Buttons -->
						<ul class="dorya-navigation-buttons">
							<?php foreach ( $buttons as $button => $link ) {
								echo '<li class="dorya-navigation-buttons__item">';
									echo '<a href="' . esc_url( $link['link_url'] ) . '" class="dorya-navigation-buttons__url">';
										echo '<span class="dorya-navigation-buttons__icon ' . esc_attr( $link['icon'] ) . '"></span>';
										echo '<span class="dorya-navigation-buttons__label">' . esc_html( $link['link_text'] ) . '</span>';
									echo '</a>';
								echo '</li>';
							}	?>
						</ul>

						<!-- Installation Video -->
						<iframe width="880" height="400" src="https://www.youtube.com/embed/vXjonvErGWY" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
						
					</div> <!-- .body -->
				</div> <!-- .content -->
				
				<aside class="dorya-grid-sidebar">
					<div class="dorya-grid-sidebar-widget-area">

						<div class="dorya-widget">
							<h2 class="dorya-widget-title"><?php echo esc_html__( 'Useful Links', 'dorya' ); ?></h2>
							<ul class="dorya-useful-links">
								<li>
									<a href="https://docs.deothemes.com/dorya" target="_blank"><?php echo esc_html__( 'Knowledge Base', 'dorya' ); ?></a>
								</li>
								<li>
									<a href="<?php echo esc_url( admin_url( 'themes.php?page=dorya-theme-contact' ) ); ?>"><?php echo esc_html__( 'Support', 'dorya' ); ?></a>
								</li>
							</ul>
						</div>

						<div class="dorya-widget dorya-widget-video-tutorials">
							<h2 class="dorya-widget-title"><?php esc_html_e( 'Video Tutorials', 'dorya' ) ?></h2>
							<ul class="dorya-video-tutorials">
								<?php
								foreach ( (array) $videos as $video_items => $video ) {
									echo '<li class="dorya-video-tutorials__item">';
										foreach ( $video['links'] as $key => $link ) {
											echo '<a href="' . esc_url( $link['link_url'] ) . '" class="dorya-video-tutorials__url" target="_blank" rel="noopener">';
												echo '<img src="' . esc_url( $link['link_img_src'] ) . '" alt="' . esc_html( $link['link_text'] ) . '" class="dorya-video-tutorials__img" />';
												echo '<span class="dorya-video-tutorials__label">' . esc_html( $link['link_text'] ) . '</span>';
											echo '</a>';
										}
									echo '</li>';
								}
								?>
							</ul>
						</div>					

					</div>					
				</aside>	

			</div> <!-- .grid -->

		</div>
	<?php
}


/**
* Adds an admin notice upon successful activation.
*/
function dorya_activation_admin_notice() {
	global $current_user;
	global $current_screen;

	// Don't show on Dorya main admin page
	if ( $current_screen->id === 'appearance_page_dorya-theme' || $current_screen->id === 'toplevel_page_dorya' ) {
		return;
	}

	if ( is_admin() ) {

		$current_theme = wp_get_theme();
		$welcome_dismissed = get_user_meta( $current_user->ID, 'dorya_wizard_admin_notice' );

		if ( ( $current_theme->get('Name') == "Dorya" || $current_theme->get('Name') == "Dorya Pro" ) && ! $welcome_dismissed ) {
			add_action( 'admin_notices', 'dorya_wizard_admin_notice', 99 );
		}

		wp_enqueue_style( 'dorya-wizard-notice-css', get_template_directory_uri() . '/assets/admin/css/wizard-notice.css' );

	}
}
add_action( 'current_screen', 'dorya_activation_admin_notice' );



/**
* Adds a button to dismiss the notice
*/
function dorya_dismiss_wizard_notice() {
	global $current_user;
	$user_id = $current_user->ID;

	if ( isset( $_GET['dorya_wizard_dismiss'] ) && $_GET['dorya_wizard_dismiss'] == '1' ) {
		add_user_meta( $user_id, 'dorya_wizard_admin_notice', 'true', true );
	}
}
add_action( 'admin_init', 'dorya_dismiss_wizard_notice', 1 );


/**
* Display an admin notice linking to the wizard screen
*/
function dorya_wizard_admin_notice() {
	if ( current_user_can( 'customize' ) ) : ?>
		<div class="notice theme-notice">
			<div class="theme-notice-logo">
				<img src="<?php echo esc_url( DORYA_URI . '/assets/admin/img/theme_logo_white.png' ); ?>" alt="<?php esc_attr_e( 'Dorya', 'dorya' ) ?>">
			</div>
			<div class="theme-notice-message wp-theme-fresh">
				<h2><?php esc_html_e( 'Thank you for choosing Dorya!', 'dorya' ); ?></h2>
				<?php if ( class_exists( 'Merlin' ) ) : ?>
					<p class="about-description"><?php esc_html_e( 'Run the Setup Wizard to configure your new theme and begin customizing your site.', 'dorya' ); ?></p>
				<?php else : ?>
					<p class="about-description"><?php esc_html_e( 'Follow the steps to configure your new theme and begin customizing your site.', 'dorya' ); ?></p>
				<?php endif; ?>
			</div>
			<div class="theme-notice-cta">
				<?php if ( class_exists( 'Merlin' ) ) : ?>
					<a href="<?php echo esc_url( admin_url( 'themes.php?page=merlin' ) ); ?>" class="button button-primary button-hero" style="text-decoration: none;"><?php esc_html_e( 'Run Setup Wizard', 'dorya' ); ?></a>
				<?php else : ?>
					<a href="<?php echo esc_url( admin_url( 'themes.php?page=dorya-theme' ) ); ?>" class="button button-primary button-hero" style="text-decoration: none;"><?php esc_html_e( 'Setup Instructions', 'dorya' ); ?></a>
				<?php endif; ?>
				<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( 'dorya_wizard_dismiss', '1' ) ) ); ?>" class="notice-dismiss" target="_parent"></a>
			</div>
		</div>
	<?php endif;
}
