<?php
/**
 * Theme Customizer
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Dorya
 * @since 		 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

function dorya_customize_register( $wp_customize ) {

	// Customize Background Settings
	$wp_customize->get_section('background_image')->title = esc_html__('Background Styles', 'dorya');  
	$wp_customize->get_control('background_color')->section = 'background_image';

	// Remove colors section
	$wp_customize->remove_section('colors');
}
add_action( 'customize_register', 'dorya_customize_register' );

// Check if Kirki is installed
if ( class_exists( 'Kirki' ) ) {

	function dorya_customizer_options() {

		// Selector Vars 
		$selectors = array(

			'headings'        =>
				'h1,h2,h3,h4,h5,h6,
				.editor-post-title__input,
				.footer__nav-menu > li > a,
				.footer .widget_nav_menu,
				.widget-about-us,
				.comment-author',

			'h1'              => 'h1, .h1',
			'h2'              => 'h2, .h2',
			'h3'              => 'h3, .h3',
			'h4'              => 'h4, .h4',
			'h5'              => 'h5, .h5',
			'h6'              => 'h6, .h6',

			'base_font'				=> 'body',

			'buttons'					=>
				'input[type="button"],
				input[type="reset"],
				input[type="submit"],
				button,
				.btn,
				.button,
				.wp-block-button .wp-block-button__link'
		);

		if ( function_exists( 'dorya_get_typekit_fonts') ) {
			$typekit_fonts = dorya_get_typekit_fonts();
		}

		$heading_font = ( isset( $typekit_fonts ) && ! empty( $typekit_fonts && isset( $typekit_fonts[0] ) ) ) ? $typekit_fonts[0] : 'Montserrat';
		$body_font = ( isset( $typekit_fonts ) && ! empty( $typekit_fonts && isset( $typekit_fonts[1] ) ) ) ? $typekit_fonts[1] : 'Archivo';
		$border_color = '#dadada';
		$primary_color = '#0052f8';
		$secondary_color = '#ffc62d';
		$heading_color = '#000000';
		$text_color = '#262626';
		$background_color = '#ffffff';
		$bg_light_color = '#f9f9f9';
		$bg_dark_color = '#1b1b1b';
		$mobile_menu_dividers_color = '#e3e3e3';
		$container_width = '1680';

		$bp_xxl_up   = '@media (min-width: 1800px)';
		$bp_xxl_down = '@media (min-width: 1799px)';
		$bp_xl_up   = '@media (min-width: 1440px)';
		$bp_xl_down = '@media (min-width: 1439px)';
		$bp_lg_up   = '@media (min-width: 1025px)';
		$bp_lg_down = '@media (max-width: 1024px)';
		$bp_md_up   = '@media (min-width: 768px)';
		$bp_md_down = '@media (max-width: 767px)';

		// Kirki
		Kirki::add_config( 'dorya_settings_config', array(
			'capability'    => 'edit_theme_options',
			'option_type'   => 'theme_mod',
			'option_name'   => 'dorya_settings_config'
		) );	


		/**
		* SECTIONS / PANELS
		**/

		$priority = 20;
		$uniqid = 1;


		// 1. GENERAL
		Kirki::add_section( 'dorya_settings_general', array(
			'title'       => esc_attr__( 'General', 'dorya' ),
			'priority'    => $priority++,
		) );

		// 2. HEADER PANEL
		Kirki::add_panel( 'dorya_settings_header', array(
			'title'          => esc_html__( 'Header', 'dorya' ),
			'priority'       => $priority++,
		) );

				// Header
				Kirki::add_section( 'dorya_settings_default_header', array(
					'title'          => esc_html__( 'Header', 'dorya' ),
					'panel'			 		 => 'dorya_settings_header',
				) );

				// Logo
				Kirki::add_section( 'dorya_settings_logo', array(
					'title'          => esc_html__( 'Logo', 'dorya' ),
					'panel'			 		 => 'dorya_settings_header',
				) );

				// Primary Menu
				Kirki::add_section( 'dorya_settings_primary_menu', array(
					'title'          => esc_html__( 'Menu', 'dorya' ),
					'panel'			 		 => 'dorya_settings_header',
				) );

				// Top Bar
				Kirki::add_section( 'dorya_settings_top_bar', array(
					'title'          => esc_html__( 'Top Bar', 'dorya' ),
					'panel'			 		 => 'dorya_settings_header',
				) );


		// 3. FOOTER
		Kirki::add_section( 'dorya_settings_footer', array(
			'title'       => esc_html__( 'Footer', 'dorya' ),
			'priority'    => $priority++,
		) );

		// 4. LAYOUT PANEL
		Kirki::add_panel( 'dorya_settings_layout', array(
			'title'          => esc_html__( 'Layout', 'dorya' ),
			'priority'       => $priority++,
		) );

				// Content
				Kirki::add_section( 'dorya_settings_content_layout', array(
					'title'          => esc_html__( 'Content', 'dorya' ),
					'panel'			 		 => 'dorya_settings_layout',
				) );

				// Blog Layout
				Kirki::add_section( 'dorya_settings_blog_layout', array(
					'title'          => esc_html__( 'Blog', 'dorya' ),
					'description'    => esc_html__( 'Layout options for the blog pages', 'dorya' ),
					'panel'			 		 => 'dorya_settings_layout',
				) );

				// Single Post Layout
				Kirki::add_section( 'dorya_settings_single_post_layout', array(
					'title'          => esc_html__( 'Single Post', 'dorya' ),
					'panel'			 		 => 'dorya_settings_layout',
				) );

				// Projects Layout
				Kirki::add_section( 'dorya_settings_projects_layout', array(
					'title'          => esc_html__( 'Projects', 'dorya' ),
					'description'    => esc_html__( 'Layout options for the projects archive pages', 'dorya' ),
					'panel'			 		 => 'dorya_settings_layout',
				) );

				// Page Layout
				Kirki::add_section( 'dorya_settings_page_layout', array(
					'title'          => esc_html__( 'Page', 'dorya' ),
					'description'    => esc_html__( 'Layout options for the regular pages', 'dorya' ),
					'panel'			     => 'dorya_settings_layout',
				) );

				// Archive Layout
				Kirki::add_section( 'dorya_settings_archive_layout', array(
					'title'          => esc_html__( 'Archive', 'dorya' ),
					'description'    => esc_html__( 'Layout options for archive and categories pages', 'dorya' ),
					'panel'			 		 => 'dorya_settings_layout',
				) );

				// Search Results Layout
				Kirki::add_section( 'dorya_settings_search_results_layout', array(
					'title'          => esc_html__( 'Search Results', 'dorya' ),
					'description'    => esc_html__( 'Layout options for search result page', 'dorya' ),
					'panel'					 => 'dorya_settings_layout',
				) );	


		// 5. COLORS PANEL
		Kirki::add_panel( 'dorya_settings_colors', array(
			'title'          => esc_html__( 'Colors', 'dorya' ),
			'priority'       => $priority++,
		) );

			// General Colors
			Kirki::add_section( 'dorya_settings_general_colors', array(
				'title'  => esc_html__( 'General', 'dorya' ),
				'panel'	 => 'dorya_settings_colors',
			) );

			// Footer Colors
			Kirki::add_section( 'dorya_settings_footer_colors', array(
				'title'  => esc_html__( 'Footer', 'dorya' ),
				'panel'  => 'dorya_settings_colors',
			) );			
			
			if ( class_exists( 'Dorya_Core' ) ) {
				// Cookies Bar Colors
				Kirki::add_section( 'dorya_settings_cookies_bar_colors', array(
					'title'      => esc_html__( 'Cookies Bar', 'dorya' ),
					'panel'			 => 'dorya_settings_colors',
				) );
			}

		// 6. TYPOGRAPHY
		Kirki::add_section( 'dorya_settings_typography', array(
			'title'          => esc_html__( 'Typography', 'dorya' ),
			'priority'       => $priority++,
		) );

		// 7. BLOG PANEL
		Kirki::add_panel( 'dorya_settings_blog', array(
			'title'       => esc_attr__( 'Blog', 'dorya' ),
			'priority'    => $priority++,
		) );

				// Page title
				Kirki::add_section( 'dorya_settings_blog_page_title', array(
					'title'          => esc_html__( 'Page Title', 'dorya' ),
					'panel'          => 'dorya_settings_blog',
				) );

				// Post Meta
				Kirki::add_section( 'dorya_settings_post_meta', array(
					'title'          => esc_html__( 'Post Meta', 'dorya' ),
					'panel'          => 'dorya_settings_blog',
				) );

				// Single Post
				Kirki::add_section( 'dorya_settings_single_post', array(
					'title'          => esc_html__( 'Single Post', 'dorya' ),
					'panel'          => 'dorya_settings_blog',
				) );

				if ( class_exists( 'Dorya_Core' ) ) {
					// Social Share
					Kirki::add_section( 'dorya_settings_social_share', array(
						'title'          => esc_html__( 'Social Share Buttons', 'dorya' ),
						'panel'          => 'dorya_settings_blog',
					) );
				}

				// Post Excerpt
				Kirki::add_section( 'dorya_settings_post_excerpt', array(
					'title'          => esc_html__( 'Excerpt', 'dorya' ),
					'panel'          => 'dorya_settings_blog',
				) );

				// Read More
				Kirki::add_section( 'dorya_settings_read_more', array(
					'title'          => esc_html__( 'Read More', 'dorya' ),
					'panel'          => 'dorya_settings_blog',
				) );

		// 8. PAGE TITLE
		Kirki::add_section( 'dorya_settings_page_title', array(
			'title'       => esc_attr__( 'Page Title / Breadcrumbs', 'dorya' ),
			'priority'    => $priority++,
		) );		

		if ( class_exists( 'Dorya_Core' ) ) {

			// 9. Socials
			Kirki::add_section( 'dorya_settings_socials', array(
				'title'          => esc_html__( 'Socials', 'dorya' ),
				'description'    => esc_html__( 'Socials options. Paste your social profile links here', 'dorya'  ),
				'priority'       => $priority++,
			) );

			// 10. GDPR
			Kirki::add_section( 'dorya_settings_gdpr', array(
				'title'          => esc_html__( 'GDPR', 'dorya' ),
				'description'    => esc_html__( 'Settings for GDPR compliance.', 'dorya'  ),
				'priority'       => $priority++,
			) );

		}

		// 12. Page 404
		Kirki::add_section( 'dorya_settings_page_404', array(
			'title'          => esc_html__( 'Page 404', 'dorya' ),
			'description'    => esc_html__( 'Settings for page 404', 'dorya' ),
			'priority'       => $priority++,
		) );

		// Load modules
		require_once DORYA_DIR . '/includes/customizer/modules/general.php';
		require_once DORYA_DIR . '/includes/customizer/modules/header.php';
		require_once DORYA_DIR . '/includes/customizer/modules/footer.php';	
		require_once DORYA_DIR . '/includes/customizer/modules/layout.php';
		require_once DORYA_DIR . '/includes/customizer/modules/page-title.php';
		require_once DORYA_DIR . '/includes/customizer/modules/blog.php';
		require_once DORYA_DIR . '/includes/customizer/modules/colors.php';
		require_once DORYA_DIR . '/includes/customizer/modules/typography.php';

		if ( class_exists( 'Dorya_Core' ) ) {
			require_once DORYA_DIR . '/includes/customizer/modules/socials.php';
			require_once DORYA_DIR . '/includes/customizer/modules/gdpr.php';
		}

		require_once DORYA_DIR . '/includes/customizer/modules/page-404.php';

	}

	dorya_customizer_options();		

} // endif Kirki check