<?php
/**
 * Customizer Header
 *
 * @package Dorya
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

// Show header
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'toggle',
	'settings'    => 'dorya_settings_header_show',
	'label'       => esc_html__( 'Show header', 'dorya' ),
	'section'     => 'dorya_settings_default_header',
	'default'     => true,
) );

// Sticky header
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'toggle',
	'settings'    => 'dorya_settings_sticky_header',
	'label'       => esc_html__( 'Sticky header', 'dorya' ),
	'section'     => 'dorya_settings_default_header',
	'default'     => true,
	'active_callback' => array(
		array(
			'setting'  => 'dorya_settings_header_show',
			'operator' => '==',
			'value'    => true,
		)
	),
) );

// Header container width
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'dimension',
	'settings'    => 'dorya_settings_header_container_width',
	'label'       => esc_html__( 'Header container width', 'dorya' ),
	'description' => esc_html__( "Example: 1200px or 80%", 'dorya' ),
	'section'     => 'dorya_settings_default_header',
	'default'     => $container_width . 'px',
	'output'       => array(
		array(
			'element'     => '.dorya-header .container',
			'property'    => 'max-width',
			'media_query' => $bp_xxl_up,
		),
	),
	'active_callback' => array(
		array(
			'setting'  => 'dorya_settings_header_show',
			'operator' => '==',
			'value'    => true,
		)
	),
	'transport' => 'auto',
) );

// Header height
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'slider',
	'settings'    => 'dorya_settings_header_height',
	'label'       => esc_attr__( 'Header height', 'dorya' ),
	'description' => esc_html__( 'Will apply only on big screens', 'dorya' ),
	'section'     => 'dorya_settings_default_header',
	'default'     => 136,
	'choices'     => array(
		'min'  => '40',
		'max'  => '200',
		'step' => '1',
	),
	'output'       => array(
		array(
			'element'     => '.nav',
			'property'    => 'min-height',
			'units'       => 'px',
			'media_query' => $bp_lg_up,
		),
	),
	'active_callback' => array(
		array(
			'setting'  => 'dorya_settings_header_show',
			'operator' => '==',
			'value'    => true,
		)
	),
	'transport' => 'auto',
) );

// Header sticky height
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'slider',
	'settings'    => 'dorya_settings_header_sticky_height',
	'label'       => esc_attr__( 'Header sticky height', 'dorya' ),
	'description' => esc_html__( 'Will apply only on big screens', 'dorya' ),
	'section'     => 'dorya_settings_default_header',
	'default'     => 80,
	'choices'     => array(
		'min'  => '40',
		'max'  => '200',
		'step' => '1',
	),
	'output'       => array(
		array(
			'element'     => '.nav--sticky.sticky .nav__flex-parent',
			'property'    => 'height',
			'units'       => 'px',
			'media_query' => $bp_lg_up,
		),
	),
	'active_callback' => array(
		array(
			'setting'  => 'dorya_settings_header_show',
			'operator' => '==',
			'value'    => true,
		)
	),
	'transport' => 'auto',
) );

// Header mobile height
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'slider',
	'settings'    => 'dorya_settings_header_mobile_height',
	'label'       => esc_attr__( 'Header mobile height', 'dorya' ),
	'description' => esc_html__( 'Will apply only on mobile screens', 'dorya' ),
	'section'     => 'dorya_settings_default_header',
	'default'     => 60,
	'choices'     => array(
		'min'  => '40',
		'max'  => '200',
		'step' => '1',
	),
	'output'       => array(
		array(
			'element'     => '.nav__header',
			'property'    => 'height',
			'units'       => 'px',
			'media_query' => $bp_lg_down,
		),
		array(
			'element'     => '.nav',
			'property'    => 'min-height',
			'units'       => 'px',
			'media_query' => $bp_lg_down,
		),
	),
	'active_callback' => array(
		array(
			'setting'  => 'dorya_settings_header_show',
			'operator' => '==',
			'value'    => true,
		)
	),
	'transport' => 'auto',
) );


// Logo
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'image',
	'settings'    => 'dorya_settings_logo_dark',
	'label'       => esc_html__( 'Upload logo', 'dorya' ),
	'section'     => 'dorya_settings_logo',
	'choices'     => array(
		'save_as' => 'array',
	),
) );

// Logo width
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'slider',
	'settings'    => 'dorya_settings_header_logo_width',
	'label'       => esc_attr__( 'Header logo width', 'dorya' ),
	'section'     => 'dorya_settings_logo',
	'default'     => 125,
	'choices'     => array(
		'min'  => '10',
		'max'  => '400',
		'step' => '1',
	),
	'output'       => array(
		array(
			'element'     => '.nav__header .logo',
			'property'    => 'max-width',
			'units'       => 'px',
			'media_query' => $bp_lg_up,
		),
	),
	'transport' => 'auto',
) );


// Logo mobile width
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'slider',
	'settings'    => 'dorya_settings_header_logo_mobile_width',
	'label'       => esc_attr__( 'Header logo mobile width', 'dorya' ),
	'section'     => 'dorya_settings_logo',
	'default'     => 125,
	'choices'     => array(
		'min'  => '10',
		'max'  => '200',
		'step' => '1',
	),
	'output'       => array(
		array(
			'element'     => '.nav__header .logo',
			'property'    => 'max-width',
			'units'       => 'px',
			'media_query' => $bp_lg_down,
		),
	),
	'transport' => 'auto',
) );

// Menu items horizontal spacing
Kirki::add_field( 'dorya_settings_config', array(
	'type'        => 'slider',
	'settings'    => 'dorya_settings_header_text_links_horizontal_spacing',
	'label'       => esc_attr__( 'Menu text links horizontal spacing', 'dorya' ),
	'description' => esc_html__( 'Will apply only on big screens', 'dorya' ),
	'section'     => 'dorya_settings_primary_menu',
	'default'     => 24,
	'choices'     => array(
		'min'  => '0',
		'max'  => '60',
		'step' => '1',
	),
	'output'       => array(
		array(
			'element'     => '.nav__menu > li',
			'property'    => 'padding-left',
			'units'       => 'px',
			'media_query' => $bp_lg_up,
		),
		array(
			'element'     => '.nav__menu > li',
			'property'    => 'padding-right',
			'units'       => 'px',
			'media_query' => $bp_lg_up,
		),
	),
	'active_callback' => array(
		array(
			'setting'  => 'dorya_settings_header_show',
			'operator' => '==',
			'value'    => true,
		)
	),
	'transport' => 'auto',
) );