<?php
/**
 * Merlin WP configuration file.
 *
 * @package   Merlin WP
 * @version   @@pkg.version
 * @link      https://merlinwp.com/
 * @author    Rich Tabor, from ThemeBeans.com & the team at ProteusThemes.com
 * @copyright Copyright (c) 2018, Merlin WP of Inventionn LLC
 * @license   Licensed GPLv3 for Open Source Use
 */

if ( ! class_exists( 'Merlin' ) ) {
	return;
}

/**
 * Set directory locations, text strings, and settings.
 */
$wizard = new Merlin(

	$config = array(
		'directory'            => 'includes/merlin', // Location / directory where Merlin WP is placed in your theme.
		'merlin_url'           => 'merlin', // The wp-admin page slug where Merlin WP loads.
		'parent_slug'          => 'themes.php', // The wp-admin parent page slug for the admin menu item.
		'capability'           => 'manage_options', // The capability required for this menu to be displayed to the user.
		'child_action_btn_url' => 'https://codex.wordpress.org/child_themes', // URL for the 'child-action-link'.
		'dev_mode'             => false, // Enable development mode for testing.
		'ready_big_button_url' => home_url( '/' ), // Link for the big button on the ready step.
	),
	$strings = array(
		'admin-menu'               => esc_html__( 'Theme Setup', 'dorya' ),

		/* translators: 1: Title Tag 2: Theme Name 3: Closing Title Tag */
		'title%s%s%s%s'            => esc_html__( '%1$s%2$s Themes &lsaquo; Theme Setup: %3$s%4$s', 'dorya' ),
		'return-to-dashboard'      => esc_html__( 'Return to the dashboard', 'dorya' ),
		'ignore'                   => esc_html__( 'Disable this wizard', 'dorya' ),

		'btn-skip'                 => esc_html__( 'Skip', 'dorya' ),
		'btn-next'                 => esc_html__( 'Next', 'dorya' ),
		'btn-start'                => esc_html__( 'Start', 'dorya' ),
		'btn-no'                   => esc_html__( 'Cancel', 'dorya' ),
		'btn-plugins-install'      => esc_html__( 'Install', 'dorya' ),
		'btn-child-install'        => esc_html__( 'Install', 'dorya' ),
		'btn-content-install'      => esc_html__( 'Install', 'dorya' ),
		'btn-import'               => esc_html__( 'Import', 'dorya' ),
		'btn-license-activate'     => esc_html__( 'Upgrade', 'dorya' ),

		/* translators: Theme Name */
		'pro-version-header%s'		 => esc_html__( '%s Pro Features', 'dorya' ),
		'pro-version-text%s'			 => esc_html__( 'Build better websites with %s Pro. Save tons of time.', 'dorya' ),

		/* translators: Theme Name */
		'welcome-header%s'         => esc_html__( 'Welcome to %s', 'dorya' ),
		'welcome-header-success%s' => esc_html__( 'Hi. Welcome back', 'dorya' ),
		'welcome%s'                => esc_html__( 'This wizard will set up your theme, install plugins, and import content. It should take only a few minutes.', 'dorya' ),
		'welcome-success%s'        => esc_html__( 'You may have already run this theme setup wizard. If you would like to proceed anyway, click on the "Start" button below.', 'dorya' ),

		'child-header'             => esc_html__( 'Install Child Theme', 'dorya' ),
		'child-header-success'     => esc_html__( 'You\'re good to go!', 'dorya' ),
		'child'                    => esc_html__( 'Let\'s build & activate a child theme so you may easily make theme changes.', 'dorya' ),
		'child-success%s'          => esc_html__( 'Your child theme has already been installed and is now activated, if it wasn\'t already.', 'dorya' ),
		'child-action-link'        => esc_html__( 'Learn about child themes', 'dorya' ),
		'child-json-success%s'     => esc_html__( 'Awesome. Your child theme has already been installed and is now activated.', 'dorya' ),
		'child-json-already%s'     => esc_html__( 'Awesome. Your child theme has been created and is now activated.', 'dorya' ),

		'plugins-header'           => esc_html__( 'Install Plugins', 'dorya' ),
		'plugins-header-success'   => esc_html__( 'You\'re up to speed!', 'dorya' ),
		'plugins'                  => esc_html__( 'Let\'s install some essential WordPress plugins to get your site up to speed.', 'dorya' ),
		'plugins-success%s'        => esc_html__( 'The required WordPress plugins are all installed and up to date. Press "Next" to continue the setup wizard.', 'dorya' ),
		'plugins-action-link'      => esc_html__( 'Advanced', 'dorya' ),

		'import-header'            => esc_html__( 'Import Content', 'dorya' ),
		'import'                   => esc_html__( 'Let\'s import content to your website. This could take some minutes. Please wait.', 'dorya' ),
		'import-demo-link'         => sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://dorya.deothemes.com', esc_html__( 'Explore Demos', 'dorya' ) ),
		'import-action-link'       => esc_html__( 'Advanced', 'dorya' ),

		'ready-header'             => esc_html__( 'All done. Have fun!', 'dorya' ),

		/* translators: Theme Author */
		'ready%s'                  => esc_html__( 'Your theme has been all set up. Enjoy your new theme by %s.', 'dorya' ),
		'ready-action-link'        => esc_html__( 'Extras', 'dorya' ),
		'ready-big-button'         => esc_html__( 'View your website', 'dorya' ),
		'ready-link-1'             => sprintf( '<a href="%1$s" target="_blank">%2$s</a>', 'https://docs.deothemes.com/dorya/', esc_html__( 'Documentation', 'dorya' ) ),
		'ready-link-2'             => sprintf( '<a href="%1$s" target="_blank">%2$s</a>', admin_url( 'themes.php?page=dorya-theme-contact' ), esc_html__( 'Get Theme Support', 'dorya' ) ),
		'ready-link-3'             => sprintf( '<a href="%1$s">%2$s</a>', admin_url( 'customize.php' ), esc_html__( 'Start Customizing', 'dorya' ) ),
	),
	$features = array(
		array(
			'title' => esc_html__( '2 Home page demos', 'dorya' ),
			'url' 	=> 'https://dorya.deothemes.com',
		),
		array(
			'title' => esc_html__( '2 Header layouts', 'dorya' ),
			'url' 	=> 'https://docs.deothemes.com/dorya/knowledgebase/header-layouts',
		),
		array(
			'title' => esc_html__( '2 Single post layouts', 'dorya' ),
			'url' 	=> 'https://docs.deothemes.com/dorya/knowledgebase/single-post-layouts',
		),
		array(
			'title' => esc_html__( 'Premium blocks', 'dorya' ),
			'url' 	=> 'https://docs.deothemes.com/dorya/knowledgebase/premium-blocks',
		),
		array(
			'title' => esc_html__( 'Google map', 'dorya' ),
			'url' 	=> 'https://docs.deothemes.com/dorya/knowledgebase/premium-blocks',
		),
		array(
			'title' => esc_html__( 'GDPR Tools', 'dorya' ),
			'url' 	=> 'https://dorya.deothemes.com/gdpr-tools',
		),
		array(
			'title' => esc_html__( 'ACF Pro included (Save $49)', 'dorya' ),
			'url' 	=> 'https://docs.deothemes.com/dorya/knowledgebase/premium-plugins/',
		),
		array(
			'title' => esc_html__( 'Dynamic portfolio', 'dorya' ),
			'url' 	=> 'https://docs.deothemes.com/dorya/knowledgebase/dynamic-custom-post-types/',
		),
	)
);
