<?php
/**
 * Template parts.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Dorya
 * @since 		 1.0.0
 */

add_action( 'dorya_header', 'dorya_header_markup' );
add_action( 'dorya_footer', 'dorya_footer_template' );
add_action( 'dorya_comments', 'dorya_comments_template' );
add_action( 'dorya_page_title_after', 'dorya_breadcrumbs' );
add_action( 'dorya_entry_section_before', 'dorya_breadcrumbs' );
add_action( 'dorya_entry_featured_image', 'dorya_featured_image_markup' );


if ( ! function_exists( 'dorya_header_markup' ) ) {
	/**
	* Get site Header
	*/
	function dorya_header_markup() {
		if ( ! get_theme_mod( 'dorya_settings_header_show', true ) ) {
			return;
		}
		get_template_part( 'template-parts/header/header-default-template' );		
	}
}

if ( ! function_exists( 'dorya_menu_mobile' ) ) {
	/**
	* Mobile menu
	*/
	function dorya_menu_mobile() { ?>
		<div class="nav__mobile d-lg-none">

			<?php if ( has_nav_menu('primary-menu') ) : ?>
				<!-- Mobile toggle -->
				<button type="button" class="nav__icon-toggle" id="nav__icon-toggle" data-bs-toggle="collapse" data-bs-target="#navbar-collapse">
					<span class="visually-hidden"><?php esc_html_e( 'Toggle navigation', 'dorya' ); ?></span>
					<span class="nav__icon-toggle-bar"></span>
					<span class="nav__icon-toggle-bar"></span>
					<span class="nav__icon-toggle-bar"></span>
				</button>
			<?php endif; ?>

		</div>
		<?php
	}
}

if ( ! function_exists( 'dorya_logo' ) ) {
	/**
	* Logo
	*/
	function dorya_logo() {
		$width = get_theme_mod( 'dorya_settings_header_logo_width' );
		$logo = get_theme_mod( 'dorya_settings_logo_dark' );
		$size = ( is_customize_preview() ) ? 'full' : [ $width, 0 ];
		?>

		<!-- Logo -->
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="logo-url logo-dark" itemtype="https://schema.org/Organization" itemscope="itemscope">
			<?php if ( isset( $logo['id'] ) ) : ?>
				<img src="<?php echo esc_url( $logo['url'] ) ?>"
				class="logo logo--dark"
				width="<?php echo esc_attr( $logo['width'] ); ?>"
				height="<?php echo esc_attr( $logo['height'] ); ?>"
				alt="<?php bloginfo( 'name' ) ?>" />
			<?php else : ?>
				<span class="site-title site-title--dark"><?php bloginfo( 'name' ) ?></span>
				<?php $tagline = get_bloginfo( 'description', 'display' ); ?>
				<p class="site-tagline"><?php echo esc_html( $tagline ); ?></p>
			<?php endif; ?>
		</a>

		<?php
	}
}

if ( ! function_exists( 'dorya_dark_mode_toggle' ) ) {
	/**
	* Dark mode toggle
	*/
	function dorya_dark_mode_toggle( $display = '' ) {
		if ( get_theme_mod( 'dorya_settings_dark_mode', false ) ) : ?>
			<button	class="js-dark-mode-trigger dark-mode-button <?php echo esc_attr( $display ); ?>">
				<span class="dark-mode-button__handle">
					<svg
						xmlns="http://www.w3.org/2000/svg"
						viewBox="0 0 24 24"
						width="14"
						height="14"
						class="dark-mode-button__icon dark-mode-button__icon--dark"
					>
						<path fill="none" d="M0 0h24v24H0z" />
						<path d="M12 18a6 6 0 1 1 0-12 6 6 0 0 1 0 12zM11 1h2v3h-2V1zm0 19h2v3h-2v-3zM3.515 4.929l1.414-1.414L7.05 5.636 5.636 7.05 3.515 4.93zM16.95 18.364l1.414-1.414 2.121 2.121-1.414 1.414-2.121-2.121zm2.121-14.85l1.414 1.415-2.121 2.121-1.414-1.414 2.121-2.121zM5.636 16.95l1.414 1.414-2.121 2.121-1.414-1.414 2.121-2.121zM23 11v2h-3v-2h3zM4 11v2H1v-2h3z" />
					</svg>
					<svg
						xmlns="http://www.w3.org/2000/svg"
						viewBox="0 0 24 24"
						width="14"
						height="14"
						class="dark-mode-button__icon dark-mode-button__icon--light"
					>
						<path fill="none" d="M0 0h24v24H0z" />
						<path d="M11.38 2.019a7.5 7.5 0 1 0 10.6 10.6C21.662 17.854 17.316 22 12.001 22 6.477 22 2 17.523 2 12c0-5.315 4.146-9.661 9.38-9.981z" />
					</svg>
				</span>
			</button>
		<?php endif;
	}
}


if ( ! function_exists( 'dorya_footer_template' ) ) {
	/**
	* Footer main template
	*/
	function dorya_footer_template() {
		get_template_part( 'template-parts/footer/footer-default-template' );
	}
}

if ( ! function_exists( 'dorya_comments_template' ) ) {
	/**
	* Comments template
	*/
	function dorya_comments_template() {
	
		if ( comments_open() || get_comments_number() ) : ?>
			<!-- Comments -->
			<div class="comments-wrap">
			<?php comments_template(); ?>
		<?php endif;
	}
}

if ( ! function_exists( 'dorya_preloader' ) ) {
	/**
	* Preloader
	*/
	function dorya_preloader() {
		$logo = get_theme_mod( 'dorya_settings_preloader_image', array( 'url' => DORYA_URI . '/assets/img/logo_white@2x.png', 'id' => 0, 'width' => 125, 'height' => 39 ) );
		
		if ( get_theme_mod( 'dorya_settings_preloader_show', false ) ) : ?>
			<div class="loader-mask">
				<div class="loader">

					<?php if ( isset( $logo['id'] ) ) : ?>
						<img src="<?php echo esc_url( $logo['url'] ) ?>"
						class="loader-logo logo"
						width="<?php echo esc_attr( $logo['width'] ); ?>"
						height="<?php echo esc_attr( $logo['height'] ); ?>"
						alt="<?php bloginfo( 'name' ) ?>" />
					<?php endif; ?>
					
					<div class="loader-bar"><span></span></div>
					<?php echo esc_html__( 'Loading...', 'dorya' ); ?>
				</div>
			</div>
		<?php endif;
	}
}

if ( ! function_exists( 'dorya_back_to_top' ) ) {
	/**
	* Back to top
	*/
	function dorya_back_to_top() {
		if ( get_theme_mod( 'dorya_settings_back_to_top_show', true ) ) : ?>
			<!-- Back to top -->
			<div id="back-to-top">
				<a href="#top">
					<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="20" height="20">
						<title><?php echo esc_html__( 'Back to top', 'dorya' ); ?></title>
						<path fill="none" d="M0 0h24v24H0z"/><path d="M12 10.828l-4.95 4.95-1.414-1.414L12 8l6.364 6.364-1.414 1.414z"/>
					</svg>
				</a>
			</div>
		<?php endif; 
	}
}

if ( ! function_exists( 'dorya_primary_content_markup_top' ) ) {
	/**
	* Content markup top
	*/
	function dorya_primary_content_markup_top() {
		?>
			<div class="container">
				<div class="row">
		<?php
	}
}

if ( ! function_exists( 'dorya_primary_content_markup_bottom' ) ) {
	/**
	* Content markup bottom
	*/
	function dorya_primary_content_markup_bottom() {
		?>
				</div>
			</div>
		<?php
	}
}

if ( ! function_exists( 'dorya_breadcrumbs' ) ) {
	/**
	* Breadcrumbs
	*
	* @since 1.0.0
	*/
	function dorya_breadcrumbs() {
		if ( ! function_exists( 'breadcrumb_trail' ) ) {
			return;
		}

		// Blog
		if ( is_home() && get_theme_mod( 'dorya_settings_breadcrumbs_blog_show', false ) ) {
			breadcrumb_trail( array(
				'show_browse' => false,
			) );
		}

		// Pages
		if ( is_page() && get_theme_mod( 'dorya_settings_breadcrumbs_pages_show', false ) ) {
			breadcrumb_trail( array(
				'show_browse' => false,
			) );
		}
		
		// Single post
		if ( is_single() && get_theme_mod( 'dorya_settings_single_post_breadcrumbs_show', false ) ) { ?>
			<div class="breadcrumbs-wrap">
				<div class="container">
					<?php breadcrumb_trail( array(
						'show_browse' => false,
					) ); ?>
				</div>
			</div>
			<?php
		}	
	}
}

if ( ! function_exists( 'dorya_entry_header' ) ) {
	/**
	* Single Entry Header
	*
	* @since 1.0.0
	*/
	function dorya_entry_header() {
		?>
		<section class="single-post__entry-header">
			<div class="container">
				<div class="row justify-content-center">
					<div class="col-xl-8">
						<div class="entry__meta single-post__entry-header-meta">
							<?php if ( get_theme_mod( 'dorya_settings_single_date_show', true ) ) : ?>
								<?php dorya_meta_date(); ?>
							<?php endif; ?>
							<?php if ( get_theme_mod( 'dorya_settings_single_category_show', true ) ) : ?>
								<?php dorya_meta_categories(); ?>
							<?php endif; ?>								
						</div>

						<h1 class="single-post__entry-header-title"><?php the_title(); ?></h1>

						<div class="single-post__entry-header-meta">
							<?php if ( get_theme_mod( 'dorya_settings_single_author_show', true ) ) : ?>
								<?php dorya_meta_author(); ?>
							<?php endif; ?>									
						</div>
					</div>
				</div>
			</div>
		</section>
		<?php
	}
}


if ( ! function_exists( 'dorya_featured_image_markup' ) ) {
	/**
	* Single Entry Featured Image
	*
	* @since 1.0.0
	*/
	function dorya_featured_image_markup() {
		$featured_image = get_theme_mod( 'dorya_settings_single_featured_image_show', true );

		if ( has_post_thumbnail() && $featured_image ) : ?>
			<!-- Featured Image -->
			<div class="single-post__featured-img">
				<figure class="single-post__featured-img-container">
					<?php the_post_thumbnail( 'dorya_featured_large', array( 'class' => 'single-post__featured-img-image' )); ?>
				</figure>
			</div>
		<?php endif;
	}
}